Enum style::animation::KeyframesRunningState
[−]
[src]
pub enum KeyframesRunningState {
Paused(f64),
Running,
}This structure represents wether an animation is actually running.
An animation can be running, or paused at a given time.
Variants
Paused(f64)This animation is paused. The inner field is the percentage of progress when it was paused, from 0 to 1.
RunningThis animation is actually running.