Struct style::animation::AnimationFrame
[−]
[src]
pub struct AnimationFrame {
pub property_animation: PropertyAnimation,
pub duration: f64,
}A single animation frame of a single property.
Fields
property_animation: PropertyAnimation
A description of the property animation that is occurring.
duration: f64
The duration of the animation. This is either relative in the keyframes case (a number between 0 and 1), or absolute in the transition case.